@@ -17,106 +17,110 @@ var NAVTREEINDEX0 =
 "changelog.html#log_1_6":[30,2],
 "changelog.html#log_1_7":[30,1],
 "changelog.html#log_1_8":[30,0],
-"changelog.html#log_1_8_0":[30,0,21],
-"changelog.html#log_1_8_1":[30,0,20],
-"changelog.html#log_1_8_10":[30,0,7],
-"changelog.html#log_1_8_11":[30,0,6],
-"changelog.html#log_1_8_12":[30,0,5],
-"changelog.html#log_1_8_13":[30,0,4],
-"changelog.html#log_1_8_14":[30,0,3],
-"changelog.html#log_1_8_15":[30,0,2],
-"changelog.html#log_1_8_16":[30,0,1],
-"changelog.html#log_1_8_17":[30,0,0],
-"changelog.html#log_1_8_1_1":[30,0,19],
-"changelog.html#log_1_8_1_2":[30,0,18],
-"changelog.html#log_1_8_2":[30,0,17],
-"changelog.html#log_1_8_3":[30,0,16],
-"changelog.html#log_1_8_3_1":[30,0,15],
-"changelog.html#log_1_8_4":[30,0,14],
-"changelog.html#log_1_8_5":[30,0,13],
-"changelog.html#log_1_8_6":[30,0,12],
-"changelog.html#log_1_8_7":[30,0,11],
-"changelog.html#log_1_8_8":[30,0,10],
-"changelog.html#log_1_8_9":[30,0,9],
-"changelog.html#log_1_8_9_1":[30,0,8],
+"changelog.html#log_1_8_0":[30,0,24],
+"changelog.html#log_1_8_1":[30,0,23],
+"changelog.html#log_1_8_10":[30,0,10],
+"changelog.html#log_1_8_11":[30,0,9],
+"changelog.html#log_1_8_12":[30,0,8],
+"changelog.html#log_1_8_13":[30,0,7],
+"changelog.html#log_1_8_14":[30,0,6],
+"changelog.html#log_1_8_15":[30,0,5],
+"changelog.html#log_1_8_16":[30,0,4],
+"changelog.html#log_1_8_17":[30,0,3],
+"changelog.html#log_1_8_18":[30,0,2],
+"changelog.html#log_1_8_19":[30,0,1],
+"changelog.html#log_1_8_1_1":[30,0,22],
+"changelog.html#log_1_8_1_2":[30,0,21],
+"changelog.html#log_1_8_2":[30,0,20],
+"changelog.html#log_1_8_20":[30,0,0],
+"changelog.html#log_1_8_3":[30,0,19],
+"changelog.html#log_1_8_3_1":[30,0,18],
+"changelog.html#log_1_8_4":[30,0,17],
+"changelog.html#log_1_8_5":[30,0,16],
+"changelog.html#log_1_8_6":[30,0,15],
+"changelog.html#log_1_8_7":[30,0,14],
+"changelog.html#log_1_8_8":[30,0,13],
+"changelog.html#log_1_8_9":[30,0,12],
+"changelog.html#log_1_8_9_1":[30,0,11],
 "commands.html":[22],
 "commands.html#cmd_intro":[22,0],
-"commands.html#cmda":[22,130],
+"commands.html#cmda":[22,134],
 "commands.html#cmdaddindex":[22,101],
 "commands.html#cmdaddtogroup":[22,1],
-"commands.html#cmdamp":[22,177],
+"commands.html#cmdamp":[22,181],
 "commands.html#cmdanchor":[22,102],
-"commands.html#cmdarg":[22,131],
-"commands.html#cmdat":[22,175],
+"commands.html#cmdarg":[22,135],
+"commands.html#cmdat":[22,179],
 "commands.html#cmdattention":[22,57],
 "commands.html#cmdauthor":[22,58],
 "commands.html#cmdauthors":[22,59],
-"commands.html#cmdb":[22,132],
-"commands.html#cmdbackslash":[22,174],
+"commands.html#cmdb":[22,136],
+"commands.html#cmdbackslash":[22,178],
 "commands.html#cmdbrief":[22,60],
 "commands.html#cmdbug":[22,61],
-"commands.html#cmdc":[22,133],
+"commands.html#cmdc":[22,137],
 "commands.html#cmdcallergraph":[22,4],
 "commands.html#cmdcallgraph":[22,2],
 "commands.html#cmdcategory":[22,10],
-"commands.html#cmdchardot":[22,184],
+"commands.html#cmdchardot":[22,188],
 "commands.html#cmdcite":[22,103],
 "commands.html#cmdclass":[22,11],
-"commands.html#cmdcode":[22,134],
+"commands.html#cmdcode":[22,138],
 "commands.html#cmdcond":[22,62],
-"commands.html#cmdcopybrief":[22,136],
-"commands.html#cmdcopydetails":[22,137],
-"commands.html#cmdcopydoc":[22,135],
+"commands.html#cmdcopybrief":[22,140],
+"commands.html#cmdcopydetails":[22,141],
+"commands.html#cmdcopydoc":[22,139],
 "commands.html#cmdcopyright":[22,63],
 "commands.html#cmddate":[22,64],
-"commands.html#cmddcolon":[22,186],
+"commands.html#cmddcolon":[22,190],
 "commands.html#cmddef":[22,12],
 "commands.html#cmddefgroup":[22,13],
 "commands.html#cmddeprecated":[22,65],
 "commands.html#cmddetails":[22,66],
-"commands.html#cmddiafile":[22,145],
+"commands.html#cmddiafile":[22,149],
 "commands.html#cmddir":[22,14],
-"commands.html#cmddocbookonly":[22,138],
-"commands.html#cmddollar":[22,178],
+"commands.html#cmddocbookinclude":[22,132],
+"commands.html#cmddocbookonly":[22,142],
+"commands.html#cmddollar":[22,182],
 "commands.html#cmddontinclude":[22,116],
-"commands.html#cmddot":[22,139],
-"commands.html#cmddotfile":[22,143],
-"commands.html#cmde":[22,146],
+"commands.html#cmddot":[22,143],
+"commands.html#cmddotfile":[22,147],
+"commands.html#cmde":[22,150],
 "commands.html#cmdelse":[22,68],
 "commands.html#cmdelseif":[22,69],
-"commands.html#cmdem":[22,147],
-"commands.html#cmdemoji":[22,140],
-"commands.html#cmdendcode":[22,148],
+"commands.html#cmdem":[22,151],
+"commands.html#cmdemoji":[22,144],
+"commands.html#cmdendcode":[22,152],
 "commands.html#cmdendcond":[22,70],
-"commands.html#cmdenddocbookonly":[22,149],
-"commands.html#cmdenddot":[22,150],
-"commands.html#cmdendhtmlonly":[22,153],
+"commands.html#cmdenddocbookonly":[22,153],
+"commands.html#cmdenddot":[22,154],
+"commands.html#cmdendhtmlonly":[22,157],
 "commands.html#cmdendif":[22,71],
 "commands.html#cmdendinternal":[22,17],
-"commands.html#cmdendlatexonly":[22,154],
+"commands.html#cmdendlatexonly":[22,158],
 "commands.html#cmdendlink":[22,104],
-"commands.html#cmdendmanonly":[22,155],
-"commands.html#cmdendmsc":[22,151],
+"commands.html#cmdendmanonly":[22,159],
+"commands.html#cmdendmsc":[22,155],
 "commands.html#cmdendparblock":[22,80],
-"commands.html#cmdendrtfonly":[22,156],
+"commands.html#cmdendrtfonly":[22,160],
 "commands.html#cmdendsecreflist":[22,109],
-"commands.html#cmdenduml":[22,152],
-"commands.html#cmdendverbatim":[22,157],
-"commands.html#cmdendxmlonly":[22,158],
+"commands.html#cmdenduml":[22,156],
+"commands.html#cmdendverbatim":[22,161],
+"commands.html#cmdendxmlonly":[22,162],
 "commands.html#cmdenum":[22,15],
-"commands.html#cmdeq":[22,185],
+"commands.html#cmdeq":[22,189],
 "commands.html#cmdexample":[22,16],
 "commands.html#cmdexception":[22,72],
 "commands.html#cmdextends":[22,18],
-"commands.html#cmdfbrclose":[22,161],
-"commands.html#cmdfbropen":[22,160],
-"commands.html#cmdfcurlyclose":[22,163],
-"commands.html#cmdfcurlyopen":[22,162],
-"commands.html#cmdfdollar":[22,159],
+"commands.html#cmdfbrclose":[22,165],
+"commands.html#cmdfbropen":[22,164],
+"commands.html#cmdfcurlyclose":[22,167],
+"commands.html#cmdfcurlyopen":[22,166],
+"commands.html#cmdfdollar":[22,163],
 "commands.html#cmdfile":[22,19],
 "commands.html#cmdfn":[22,20],
-"commands.html#cmdgt":[22,181],
-"commands.html#cmdhash":[22,179],
+"commands.html#cmdgt":[22,185],
+"commands.html#cmdhash":[22,183],
 "commands.html#cmdheaderfile":[22,21],
 "commands.html#cmdhidecallergraph":[22,5],
 "commands.html#cmdhidecallgraph":[22,3],
@@ -124,11 +128,11 @@ var NAVTREEINDEX0 =
 "commands.html#cmdhiderefby":[22,7],
 "commands.html#cmdhiderefs":[22,9],
 "commands.html#cmdhtmlinclude":[22,128],
-"commands.html#cmdhtmlonly":[22,164],
+"commands.html#cmdhtmlonly":[22,168],
 "commands.html#cmdidlexcept":[22,23],
 "commands.html#cmdif":[22,73],
 "commands.html#cmdifnot":[22,74],
-"commands.html#cmdimage":[22,165],
+"commands.html#cmdimage":[22,169],
 "commands.html#cmdimplements":[22,24],
 "commands.html#cmdinclude":[22,117],
 "commands.html#cmdincludedoc":[22,119],
@@ -138,34 +142,35 @@ var NAVTREEINDEX0 =
 "commands.html#cmdinternal":[22,27],
 "commands.html#cmdinvariant":[22,75],
 "commands.html#cmdlatexinclude":[22,129],
-"commands.html#cmdlatexonly":[22,166],
-"commands.html#cmdli":[22,168],
+"commands.html#cmdlatexonly":[22,170],
+"commands.html#cmdli":[22,172],
 "commands.html#cmdline":[22,120],
 "commands.html#cmdlink":[22,105],
-"commands.html#cmdlt":[22,180],
+"commands.html#cmdlt":[22,184],
 "commands.html#cmdmainpage":[22,28],
-"commands.html#cmdmanonly":[22,167],
-"commands.html#cmdmdash":[22,189],
+"commands.html#cmdmaninclude":[22,131],
+"commands.html#cmdmanonly":[22,171],
+"commands.html#cmdmdash":[22,193],
 "commands.html#cmdmemberof":[22,29],
-"commands.html#cmdmsc":[22,141],
-"commands.html#cmdmscfile":[22,144],
-"commands.html#cmdn":[22,169],
+"commands.html#cmdmsc":[22,145],
+"commands.html#cmdmscfile":[22,148],
+"commands.html#cmdn":[22,173],
 "commands.html#cmdname":[22,30],
 "commands.html#cmdnamespace":[22,31],
-"commands.html#cmdndash":[22,188],
+"commands.html#cmdndash":[22,192],
 "commands.html#cmdnoop":[22,67],
 "commands.html#cmdnosubgrouping":[22,32],
 "commands.html#cmdnote":[22,76],
 "commands.html#cmdoverload":[22,33],
-"commands.html#cmdp":[22,170],
+"commands.html#cmdp":[22,174],
 "commands.html#cmdpackage":[22,34],
 "commands.html#cmdpage":[22,35],
 "commands.html#cmdpar":[22,77],
 "commands.html#cmdparagraph":[22,115],
 "commands.html#cmdparam":[22,78],
 "commands.html#cmdparblock":[22,79],
-"commands.html#cmdperc":[22,182],
-"commands.html#cmdpipe":[22,187],
+"commands.html#cmdperc":[22,186],
+"commands.html#cmdpipe":[22,191],
 "commands.html#cmdpost":[22,82],
 "commands.html#cmdpre":[22,83],
 "commands.html#cmdprivate":[22,36],
@@ -177,7 +182,7 @@ var NAVTREEINDEX0 =
 "commands.html#cmdpublic":[22,42],
 "commands.html#cmdpublicsection":[22,43],
 "commands.html#cmdpure":[22,44],
-"commands.html#cmdquot":[22,183],
+"commands.html#cmdquot":[22,187],
 "commands.html#cmdref":[22,106],
 "commands.html#cmdrefitem":[22,107],
 "commands.html#cmdrelated":[22,46],
@@ -190,7 +195,8 @@ var NAVTREEINDEX0 =
 "commands.html#cmdreturn":[22,87],
 "commands.html#cmdreturns":[22,88],
 "commands.html#cmdretval":[22,89],
-"commands.html#cmdrtfonly":[22,171],
+"commands.html#cmdrtfinclude":[22,130],
+"commands.html#cmdrtfonly":[22,175],
 "commands.html#cmdsa":[22,90],
 "commands.html#cmdsecreflist":[22,108],
 "commands.html#cmdsection":[22,112],
@@ -205,7 +211,7 @@ var NAVTREEINDEX0 =
 "commands.html#cmdsnippet":[22,123],
 "commands.html#cmdsnippetdoc":[22,125],
 "commands.html#cmdsnippetlineno":[22,124],
-"commands.html#cmdstartuml":[22,142],
+"commands.html#cmdstartuml":[22,146],
 "commands.html#cmdstatic":[22,50],
 "commands.html#cmdstruct":[22,51],
 "commands.html#cmdsubpage":[22,110],
@@ -215,39 +221,33 @@ var NAVTREEINDEX0 =
 "commands.html#cmdtest":[22,94],
 "commands.html#cmdthrow":[22,95],
 "commands.html#cmdthrows":[22,96],
-"commands.html#cmdtilde":[22,176],
+"commands.html#cmdtilde":[22,180],
 "commands.html#cmdtodo":[22,97],
 "commands.html#cmdtparam":[22,81],
 "commands.html#cmdtypedef":[22,52],
 "commands.html#cmdunion":[22,53],
 "commands.html#cmduntil":[22,126],
 "commands.html#cmdvar":[22,54],
-"commands.html#cmdverbatim":[22,172],
+"commands.html#cmdverbatim":[22,176],
 "commands.html#cmdverbinclude":[22,127],
 "commands.html#cmdversion":[22,98],
 "commands.html#cmdvhdlflow":[22,55],
 "commands.html#cmdwarning":[22,99],
 "commands.html#cmdweakgroup":[22,56],
-"commands.html#cmdxmlonly":[22,173],
+"commands.html#cmdxmlinclude":[22,133],
+"commands.html#cmdxmlonly":[22,177],
 "commands.html#cmdxrefitem":[22,100],
 "config.html":[21],
 "config.html#config_autogen":[21,13],
 "config.html#config_build":[21,2],
 "config.html#config_docbook":[21,12],
-"config.html#config_dot":[21,17],
-"config.html#config_examples":[21,18],
-"config.html#config_external":[21,16],
+"config.html#config_dot":[21,18],
+"config.html#config_examples":[21,19],
+"config.html#config_external":[21,17],
 "config.html#config_format":[21,0],
 "config.html#config_html":[21,7],
 "config.html#config_index":[21,6],
 "config.html#config_input":[21,4],
 "config.html#config_latex":[21,8],
-"config.html#config_man":[21,10],
-"config.html#config_messages":[21,3],
-"config.html#config_perlmod":[21,14],
-"config.html#config_preprocessor":[21,15],
-"config.html#config_project":[21,1],
-"config.html#config_rtf":[21,9],
-"config.html#config_source_browser":[21,5],
-"config.html#config_xml":[21,11]
+"config.html#config_man":[21,10]
 };
